@@ -4,14 +4,16 @@ use std::time::Duration;
 
 #[derive(Debug)]
 pub struct PingClientPingResultDetails {
+    pub actual_local_addr: Option<SockAddr>,
     pub round_trip_time: Duration,
     pub inner_error: Option<io::Error>,
 }
 pub type PingClientPingResult = std::result::Result<PingClientPingResultDetails, PingClientPingResultDetails>;
 
 impl PingClientPingResultDetails {
-    pub fn new(round_trip_time: Duration, inner_error: Option<io::Error>) -> PingClientPingResultDetails {
+    pub fn new(actual_local_addr: Option<SockAddr>, round_trip_time: Duration, inner_error: Option<io::Error>) -> PingClientPingResultDetails {
         PingClientPingResultDetails {
+            actual_local_addr,
             round_trip_time,
             inner_error,
         }
@@ -21,6 +23,7 @@ impl PingClientPingResultDetails {
 impl From<io::Error> for PingClientPingResultDetails {
     fn from(e: io::Error) -> PingClientPingResultDetails {
         PingClientPingResultDetails {
+            actual_local_addr: None,
             round_trip_time: Duration::from_secs(0),
             inner_error: Some(e),
         }
